package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````!1<``#0```"(`0$```0`!30`(``)
M`"@`&P`:``$``'!L?```;'P``&Q\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!X?```>'P```4```````$`
M`0```*S]``"L_0$`K/T!`)0"``"H$@``!@```````0`"````M/T``+3]`0"T
M_0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DK/T`
M`*S]`0"L_0$`5`(``%0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`S?=RS9Z5G(NM2(H(F]%],6-"5LL$
M````$`````$```!'3E4```````,````"`````````!$```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"$P```!-````4```
M`%0```!5````70```%X```!?````80```&(```!D````90```&8```!G````
M:@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,9D)%
MU>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[
M20``````````````````````````/!(````````#``L``````````@``````
M`P`6`$`"`````````````!(```#4`@`````````````2````J`(`````````
M````(@```.T"`````````````!$```":`P`````````````2`````0``````
M````````(````*8!`````````````!(```"'`@`````````````2````Q0(`
M````````````$@```/@``````````````!(````)`P`````````````1````
M6P(`````````````$@```%P!`````````````!(```!B`@`````````````2
M````1P(`````````````$@```'0``````````````!(```#S````````````
M```2````:@(`````````````$@```"0"`````````````!(```#J`0``````
M```````2````]P(`````````````$@```&,"`````````````!(```#[`0``
M```````````2````"`(`````````````$@```-$``````````````!$```!.
M`0`````````````2````LP``````````````$0```!P!`````````````!(`
M``".`@`````````````2````@`(`````````````$0```(H!````````````
M`!(```"R`0`````````````2````=P$`````````````$@```'@"````````
M`````!(```"K`0`````````````2````@P$`````````````$@```-L"````
M`````````!(````J`0`````````````2````'0``````````````(````!T"
M`````````````!(```#4`0`````````````2````,@(`````````````$@``
M`%0``````````````!(```"7`@`````````````2````@P``````````````
M$@```)4!`````````````!(```"W`@`````````````2````CP``````````
M````$@```$,!`````````````!(````"`@`````````````2````.0(`````
M````````$@````D!`````````````!(```!&```````````````2````_0``
M````````````$@```&P!`````````````!(```!-`@`````````````2````
MP```````````````$@```!8"`````````````!(```#-`@`````````````2
M````W```````````````$@```"L"`````````````!(```!C````````````
M```2````[@(`````````````(0```)X"`````````````!(```"D````````
M```````2````.@$`````````````$@```"P``````````````"````#O`@``
M```````````1````V0$`````````````$@```!`"`````````````!(```#.
M`0`````````````2````X0$`````````````$@```+H!`````````````!(`
M``"W`P``5!`"```````0`!<`HP,``*$L``#H````$@`-`-L#```))0``T`4`
M`!(`#0#H`@``214``+P!```2``T`:0,``)4=```$````$@`-`'H#``!```(`
M`````!``%P!W!```F1T``*0!```2``T`K00``-DJ``#(`0``$@`-`&,$``!`
M``(``````!``%P#"`P``/1\``!8````2``T`Z`,``'DY``#4````$@`-```$
M``!D.P``!````!$`#P`_!```5!`"```````0`!<`1`0``%00`@``````$``7
M`&\$``"U'```.````!(`#0"$!```*20``.`````2``T`E@0``*$C``!X````
M$@`-`/,#``````(``````!``%@#/`P``51\``+`````2``T`KP,``$```@``
M````$``6`#4$```\``(`!````!$`%@!9`P``23L```(````2``T`)00```D[
M``!`````$@`-`/D#```%%P```````!(`#0"D!````3D``'@````2``T`]0,`
M`````@``````(``6`(@#```9)```$````!(`#0"V`P``5!`"```````0`!<`
M#P0``.T<``"H````$@`-`%D$``!-.@``O````!(`#0!,!```!2```)P#```2
M``T``%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V
M;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`%!E
M<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`7U]E<G)N;U]L;V-A=&EO;@!R96%D`&]P96XV-`!L<V5E:S8T`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?
M<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M
M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`&QS=&%T-C0`7U]S=')N8W!Y
M7V-H:P!O<&5N9&ER`'-T9&5R<@!G971U:60`<F5A9&QI;FL`<W1R8VAR`')E
M861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`
M86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R
M96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU
M+C,T`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M;&EN=7@M87)M:&8N
M<V\N,P!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S
M=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`
M<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I
M;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`
M;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E;G8`<VAA7V9I;F%L
M`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?26YT97)N86QS7U!!
M4E]"3T]4`$=,24)#7S(N-`!'3$E"0U\R+C,S``````````(``@`"``(``@`!
M``,``@`"``(`!``"``$`!0`"``$``0`"``(``@`"``4``@`"``$``0`!``$`
M`@`"``$``P`!``(``P`"``(``0`!``(``@`"``$``@`!``,``@`!``$``@`"
M``$``0`!``$``@`!``(``@`!``(``0`"``(``0`!``$``@`"``(``P`"``,`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0````$``0!%`P``$````"`````4:6D-```$`,,$
M`````````0`!`"L#```0````(````!1I:0T```,`PP0````````!``(`.P,`
M`!``````````LY&6!@``!0#-!```$````!1I:0T```(`PP0```````"L_0$`
M%P```+#]`0`7````Q/\!`!<```#H_P$`%P```/#_`0`7````!``"`!<````,
M``(`%P```!```@`7````&``"`!<````<``(`%P```"```@`7````)``"`!<`
M```H``(`%P```#```@`7````-``"`!<````\``(`%P```,C_`0`5!0``S/\!
M`!4(``#0_P$`%0T``-3_`0`5#P``V/\!`!4;``#<_P$`%1T``.#_`0`5(```
MY/\!`!4I``#L_P$`%38``/3_`0`50```^/\!`!5%``#\_P$`%48``-#^`0`6
M`P``U/X!`!8$``#8_@$`%@4``-S^`0`6!P``X/X!`!8)``#D_@$`%@H``.C^
M`0`6"P``[/X!`!8,``#P_@$`%@X``/3^`0`6$```^/X!`!81``#\_@$`%A(`
M``#_`0`6$P``!/\!`!84```(_P$`%A4```S_`0`6%@``$/\!`!87```4_P$`
M%A@``!C_`0`6&0``'/\!`!8:```@_P$`%AP``"3_`0`6'@``*/\!`!8?```L
M_P$`%B$``##_`0`6(@``-/\!`!8C```X_P$`%B0``#S_`0`6)0``0/\!`!8F
M``!$_P$`%B<``$C_`0`6*```3/\!`!8I``!0_P$`%BH``%3_`0`6*P``6/\!
M`!8L``!<_P$`%BT``&#_`0`6+@``9/\!`!8O``!H_P$`%C```&S_`0`6,0``
M</\!`!8R``!T_P$`%C,``'C_`0`6-```?/\!`!8U``"`_P$`%C<``(3_`0`6
M.```B/\!`!8Y``",_P$`%CH``)#_`0`6.P``E/\!`!8\``"8_P$`%CT``)S_
M`0`6/@``H/\!`!8_``"D_P$`%D(``*C_`0`60P``K/\!`!9$``"P_P$`%D<`
M`+3_`0`62```N/\!`!9)``"\_P$`%DH``,#_`0`62P``"$`MZ4$!`.L(@+WH
M!.`MY03@G^4.X(_@"/"^Y6SL`0``QH_B'LJ,XFS\O.4`QH_B'LJ,XF3\O.4`
MQH_B'LJ,XES\O.4`QH_B'LJ,XE3\O.4`QH_B'LJ,XDS\O.4`QH_B'LJ,XD3\
MO.4`QH_B'LJ,XCS\O.5X1_WG`,:/XA[*C.(P_+SE`,:/XA[*C.(H_+SE`,:/
MXA[*C.(@_+SE`,:/XA[*C.(8_+SE`,:/XA[*C.(0_+SE`,:/XA[*C.((_+SE
M`,:/XA[*C.(`_+SE>$?]YP#&C^(>RHSB]/N\Y0#&C^(>RHSB[/N\Y7A'_><`
MQH_B'LJ,XN#[O.4`QH_B'LJ,XMC[O.4`QH_B'LJ,XM#[O.4`QH_B'LJ,XLC[
MO.4`QH_B'LJ,XL#[O.4`QH_B'LJ,XKC[O.4`QH_B'LJ,XK#[O.4`QH_B'LJ,
MXJC[O.4`QH_B'LJ,XJ#[O.4`QH_B'LJ,XIC[O.4`QH_B'LJ,XI#[O.4`QH_B
M'LJ,XHC[O.4`QH_B'LJ,XH#[O.4`QH_B'LJ,XGC[O.4`QH_B'LJ,XG#[O.4`
MQH_B'LJ,XFC[O.4`QH_B'LJ,XF#[O.4`QH_B'LJ,XEC[O.4`QH_B'LJ,XE#[
MO.4`QH_B'LJ,XDC[O.4`QH_B'LJ,XD#[O.4`QH_B'LJ,XCC[O.4`QH_B'LJ,
MXC#[O.4`QH_B'LJ,XBC[O.4`QH_B'LJ,XB#[O.5X1_WG`,:/XA[*C.(4^[SE
M`,:/XA[*C.(,^[SE`,:/XA[*C.($^[SE`,:/XA[*C.+\^KSE`,:/XA[*C.+T
M^KSE`,:/XA[*C.+L^KSE`,:/XA[*C.+D^KSE`,:/XA[*C.+<^KSE`,:/XA[*
MC.+4^KSE`,:/XA[*C.+,^KSE`,:/XA[*C.+$^KSE`,:/XA[*C.*\^KSE`,:/
MXA[*C.*T^KSE`,:/XA[*C.*L^KSE`,:/XA[*C.*D^KSE`,:/XA[*C.*<^KSE
M`,:/XA[*C.*4^KSE`,:/XA[*C.*,^KSE`,:/XA[*C.*$^KSE`,:/XA[*C.)\
M^KSE<+5;38BP6TM]1%M,S>D$$`6H`Y($J0.J?$3K6!MH!Y-/\``#__=.[U1*
M54NB6.!8$48"\.?Z4TOC6!UX`"UKT%%+Y%@@:/_WUN\#1B!HD_C&(T+P`@*#
M^,8C__?,[P6=D/C&,RH=`S5#\`$#LO&`3X#XQC-STI``__?H[D-*!)P#1GI$
M0DEY1%!@(F@:8$%*!9AZ1-I@0$H!*`EH>D298%I@7MTA'03K@`X#\0P,4?@$
M2TSX!$]Q1?G1`S`W3@`A`)$J1GY$0_@@$#5)\&AY1/_W/.\$1GBS,DT&KGU$
MZ&C_]Y;N,$@Q1GA$`/#O^$"S+DM[1-AH__=8[O_W'.\L2AQ+>D336!IH!YM:
M0$_P``,IT2!&"+!PO?_WC.XE2GI$T&`0L__W.NX72^18(&C_]V+O@/A[5X7G
M\&C_]S[O!$;*YZAH$+$!\`?[T><:2#%&>$0`\+OXJ&``*,G0\^?_]Q3O!""J
MY__W-.X!(/_WGNYPZ0$`#`$``&#I`0`H`0``,`$``!@!```4`0``=NH!`&KJ
M`0`6*0``""D``#3J`0`S!@``'.H!`(@F```&Z@$`=N@!`-KI`0"\)0``3_``
M"T_P``X"O&I&!+0!M-_X)*`(HYI$W_@@P%KX#,!-^`3-!DM:^`,P!DA:^```
M__=&[O_W[NZ(YP$```$``"0!```L`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>
M_R\!'/__ZFCG`0`@`0``!D@'2P=*>$1[1'I$@T(#T`5+TU@#L1A'<$<`O\;H
M`0#$Z`$`1N<!``@!```(2`E+>$0)2GM$&QIZ1-D/`>NC`4D0`]`%2]-8`[$8
M1W!'`+^<Z`$`F.@!`!CG`0`T`0``"+4*2PI*>T1Z1!MX:[D)2]-8([$(2WM$
M&&C_]T3M__>__P9+`2)[1!IP"+UFZ`$`Z.8!``0!```:Z`$`1N@!`,3G`+\M
MZ?A#@48?2WM$`"@VT!Y*FUC3^`"`N/$`#S'0!7@/1@`M&+\]+12_`24`)1/1
MV/@`0&RQ1D8@1BI&24;_]USN$+EC73TK$-!6^`1/`"SRT2!&O>CX@P5&%?@!
M/P`K&+\]*_G1I>L)!>'GINL(!@$U+$2V$#Y@($:]Z/B#!$;GYT1&Y>>DY@$`
M.`$``#A*.4MZ1"WI\$&>L--8&V@=DT_P``,0L0-X!$9CN3-*,4MZ1--8&F@=
MFUI`3_```U71'K"]Z/"!__=B[05&`"CMT"M/?T0H1O_W_NT`*#70PWP`\1,&
M+BL"T7-X`"ORT,-\+BLQT"!&__=Z[8!&,$;_]W;M0$0",/_W3NT[1D_P_S(!
M(0&6!D8`E/_WB.T"J3!&__<`[0$P,$8%T`:;`_1P0[/U@$\7T/_W^NPP1O_W
MLNPH1O_WR.T`*,G1*$;_]^CM($;_][CLJ>=S>"XKRM&S>``KM]#&Y__WDO_F
MY__WS.P`OQSF`0`,`0``_N4!`!`C```72AA+>D00M01&G+#36&E&&V@;DT_P
M``/_]X[LH+D$FP/T<$.S]2!/&+^S]8!/#=`-2@Q+>D336!IH&YM:0$_P``,+
MT1RP$+T`(/'G`B$@1O_W;NVP^H#P0`GIY__WDNPHY0$`#`$``/CD`0`MZ?!#
M#D8L22Q+K?6`77E$@[`$1@WU@%`$,-_XI(#+6`&O0/;_<CE&&V@#8$_P``,D
M2/A$>$3_]YSLL/$`#!O=`JT,\?\Y3405^`0\@[NY\0`/$=!*1B\A.$;_]R[M
M6+$92UCX`S`8:/_W:.U+1CI&(4;_]T#M">`32UCX`S`8:/_W7.TR1B%&__=L
M[`]*#?6`40I+!#%Z1--8&F@+:%I`3_```P;1#?6`70.PO>CP@^%&S^?_]S#L
MLN0!``P!``".Y`$`R"$``!0!```JY`$`6$I92WI$+>GP1PQ&@K`%1M-8W_A8
M@1MH`9-/\``#"WCX1#TK"+\!-"!&__>"[&E&!D8H1O_WAOZ!1@`H5-#_]WCL
MAD)'V4I+`)]8^`.`OP`K>``K&+\]*Q2_`2,`(P?0*T83^`$O`"H8OSTJ^=%;
M&[`<V/@`8!A$__<V[/!1Z+'8^``P*$;961#X`3L+<``K&+\]*PG02AP0^`$[
M$48"^`$[/2L8OP`K]M$*1CTC"W`4^`$[`O@!/P`K^=$M2BI+>D336!IH`9M:
M0$_P``-&T0*PO>CPAPGQ_SD4^`$["?@!/P`K^='IYR%+6/@#@-CX`'`[:(.S
M.T93^`0O248)\0$)`"KXT0,QB0`;2GI$$VB[N0A&`2,38/_WYNN"1@`HS-`Y
M1D_JB0<Z1O_W5.O(^`"@S?@`D`GQ`0D`(TKX*3"&YSA&__>:ZX)&R/@````H
MM-!/ZHD'[.>91@@AU>?_]W3K`+_LXP$`#`$``-#C`0`X`0``,.,!`&3D`0`P
MM1%,$4N#L'Q$Y5@H:/_W<.PH:/_W;.P-2@Y+#DE[1*)8>43_]_+K*&C_]V+L
M"TL+2@`D"TE[1'I$S>D`-'E$__<.[`.P,+ULX@$`%`$``!`!``!B7P``GA\`
M`&8B``!1#@``GA\``!"U"$P(2WQ$XU@8:/_W/.P&2@=+!TE[1*)8>42]Z!!`
M__>^NP;B`0`4`0``$`$```)?```^'P``)$HPM21+>D2M]0!=B;`-]0!1!:S3
M6!PQ&V@+8$_P``/_]VSK'4E!\@$"'4MY1,WI``%[1`$A($;_]XKK#?6`41@Q
M($9/](!2`Y'_]QSK!!ZXOP`E"MM@'/_W..L%1BBQ`YDB1O_WMNH`(RM5#4H-
M]0!1"4L<,7I$TU@::`MH6D!/\``#!-$H1@WU`%T)L#"]__?,ZL[A`0`,`0``
M-!\``"(?``!>X0$`__>JOUM*+>GP3P9&6DMZ1*WUA%V#L%E(#?6$5`WQ&`C3
M6`U&>$1!1@0T&V@C8$_P``/_]R7]+R$$1C!&__<BZ\"Q3T@Q1GA$__=X_C!&
M34H-]8112$L$,7I$TU@::`MH6D!/\``#0/"#@`WUA%T#L+WH\(\P1O_W^NJ!
M1BA&__=\ZD%)>43_]V#K`"C9T#]+!T;?^/R@>T0%DSY+^D1[1`23.W@`*S[0
M++$Y1B!&__<2Z@`H0=`X1O_WV.I"'KL8NEPO*@;1`"4=<`$X$_@!+2\J^=`)
M\0$#`T2S]8!?L-HM2B&M`2%31GI$*$;-Z0$F3_2`4@"7__?8ZD%&*$;_]U#J
M*+D*FP/T<$.S]0!/'=`B20`@>43_]QCK!T8`+Y#0.W@`*\#1!+,C>"XK`M`%
MGP$@S^=C>``K^=$920`@>43_]P+K!T8`+^K1>N<!(2A&__?NZ@`HV]$22"E&
M>$3_]^W]*$;_]PCJ<><$GP$@L>?_]PCJ'N$!``P!``"<'@``AAX``-3@`0!8
M'@``)AX``$0>```>'@```!X``,@=``">'0``<!T```-X.[%"'"\K"+\01A+X
M`3L`*_C1<$<`OQ"UJ+,#>`1&D[/_]U#J0QXC1)Q",M(:1@+@$T:B0BW0$T82
M^`$9+RGWT)Q")M(!.YQ")=`:>"\J^=$!.P/@$7@!.R\I`M$:1IQ"^-,2&Y,<
ML_6`7XB_`"`)V!%((49/](!3`3)X1`1&__>>Z2!&$+T,2+WH$$!X1/_WG+F<
M0MS1(W@O*P70"$B]Z!!`>$3_]Y&Y!DB]Z!!`>$3_]XNY`+^8X`$`AAP``)P<
M``!D'```S$K-2WI$<+7,3H*PS$W36'Y$;$9]1!MH`9-/\``#(48P1O_W]?NP
ML<9+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__??^P`H
MZ-&\3GY$(48P1O_WU_NPL;=+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__?!^P`HZ-&N3GY$(48P1O_WN?NPL:A+`)CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>C^P`HZ-&@3GY$(48P1O_WF_NP
ML9E+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>%^P`H
MZ-&23GY$(48P1O_W??NPL8I+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__=G^P`HZ-&$3GY$(48P1O_W7_NPL7M+`)CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=)^P`HZ-%V3GY$(48P1O_W0?NP
ML6Q+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<K^P`H
MZ-%H3GY$(48P1O_W(_NPL5U+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__<-^P`HZ-%:3GY$(48P1O_W!?NPL4Y+`)CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?O^@`HZ-%,3GY$(48P1O_WY_JP
ML3]+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?1^@`H
MZ-$^3GY$(48P1O_WR?JPL3!+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__>S^@`HZ-$P2"%&>$3_]ZSZ`488L2U(>$3_]P3\+$@A1GA$
M__>A^@%&&+$J2'A$__?Y^RE((49X1/_WEOH!1K"Q)DAX1/_W[OLE2A%+>D33
M6!IH`9M:0$_P``,5T2%)(DAY1'A$`K"]Z'!`__?;NQ]((49X1/_W>/H!1@`H
MY-`<2'A$__?/^]_G_O?P[[C>`0`,`0``;!P``*C>`0`X`0``,!P``/P;``#,
M&P``F!L``&P;``#,&@```!L``-`:``"@&@``Z!D``#(:```.&@``,!H``#@:
M```Z&@``9AD``,C;`0`T&@``FAD```X:``"8&0``%TL821A*>T1Y1`"U&&B#
ML(I80QP2:`&23_```@S0$TH12WI$TU@::`&;6D!/\``#$]$#L%WX!/L-2&E&
M>$3_]QGZ,+$`>#`H&+\`*!2_`2``(`A+>T088.'G_O>.[P"_7MP!`!C;`0`,
M`0``_MH!`.@8```0W`$`"+7^]S[O_O<P[P"Q`&@(O2Y*+TMZ1/"U+DZ'L`5&
MTUA^1`2I,$8;:`633_```__WY?D0L0-X!$:+N2=*)$MZ1--8&F@%FUI`3_``
M`SS1(T@I1GA$!["]Z/!`__<MNRE&_O?P[EBQ'DH92WI$TU@::`6;6D!/\``#
M)M$'L/"]*$;^][+O!T8@1O[WKN\X1`(P_O>&[Q-+%$H!(7M$`I1Z1`"5`9)/
M\/\R!$;^][SO#TH'2WI$TU@::`6;6D!/\``#!+\A1C!&Q=#^]QKOE-H!``P!
M```,&0``:MH!`-H8```^V@$`PA<``+H7``#VV0$`+>GP3]_X-!6M]0%-W_@P
M18&PW_@PI7Q$0*\B':?Q=`,'D`WU`$7?^"`%!/$0#/PU*#1X1*?Q:`ZG\>`&
M^D1!6`EH*6!/\``!I_%<!0?*@^@'`+SH#P`/Q9SH`P"%Z`,`E.@'`([H!P#?
M^.`$,49X1/_W3/D@L0-X!$8`*T#P6('^]X;N_O=X[@`H`/!I@05H`"T`\(N!
M*$;^]R[O0``!,/[W!N\J>(!&@K'?^*2T1$;[1"!&`));1D_P_S(!(0(T_O<X
M[Q7X`2\`*O+1W_B$!*?Q7`5X1`+@5?@$#XBQ,4;_]Q3Y!$8`*/;0`W@`*_/0
M__?,^0`H[]`@1O[WA.X$1L"Y3_``":?Q=`L'ZXD"4OAT3'2Q"^N)!2)X4K$@
M1@GQ`0G_][/Y`"A9T57X!$\`+/+1`"0@1O[WX.Z#1D!&_O?<[H-$"_($2UA&
M_O>R[M_X"#1/\/\R`2%[1`*3_TO-^`R`@$9[1`&3_4L`E'M$_O?B[D_TX'%`
M1O[W\.X!,`71_O?2[@%H$2E`\,*`,49`1O[W&.X%1DBS\DD'F_)*6O@!`$_P
M``H;:'I$S?@`@`$A`&C^]_+N[4H-]0!!WTO\,7I$TU@::`MH6D!/\``#0/"S
M@5!&#?4!30&PO>CPCR!&_O<0[@1&`"B/T*/G5_C0/`/T<$.S]8!/SM%7^,A,
M_O?([81"R-%7^-`\P_,(`[/UX'_!T5A&_O=,[H)&U$@Q1GA$__=S^`%&`"@`
M\,&`!YL8:/_W+?N#1@`H`/"Y@%A&_O=:[@1&`R@/V<I)!#A81'E$_O>&[4"Y
M!"P`\"J!7$04^`4\+RL`\"2!PTQ\1"-H6AP`\*&``"L`\+.`OTG`2'E$W_@`
MDWA$OT__]YWYOT[^]R;NODM/\/\R`2%[1`.3O$OY1,WX`(!_1'M$S>D!,+E+
M4$9^1'M$_O<\[A3@_O<T[@-H$2L7T?[W"NX!-81&2T8B1@$A4$;-Z0-7S>D!
M;,WX`(#^]R;N3_3@<5!&_O<V[@1&0QSBT$!&_O=8[:=(449X1/_W8/E01O_W
M"?Y2YY1*!YM:^`(`3_``"AMHH$K-Z0"!`2%Z1`!H_O<V[D+G__?V_9M*@4L-
M]0!!>D3\,=-8&F@+:%I`3_```T#P](`@1@WU`4T!L+WH\$_^]U"]!$:G\6@(
M!^N$`U/X:`RHL0CKA`4"X%7X!`]XL3%&`33^]\3_`"CVT`-X`"OST/[W.NT%
M1@`H?_1^KN3G@DT-(/[WANU3(H!&?41^YBQ&V.<'F]/X`+!"YWQ(,49X1/[W
MI?\`*`#PBH`#>``K&+\P*Q6_`2,`(P$C(V`8OR-@?_1-KUA&`"'^]U[M!$8`
M*#_T1:]/\/\S;_`1`@(F/1\`EO[W/NT&(BE&($;^][SL%_@$/!NY%_@#/$,K
M8=``(P`B`),@1@`C_O<L[0#PY?\&1@/@*48P1@'P&_A/]`!"*48@1O[WH.P"
M'O/<W_ADL2!&I_$P"?[WXNVG\44%,4;[1$Q&I_$Q!J?Q1``!\&OX%?@!+R!&
M`));1D_P_S(!(?[W6NT"-*Y"\M%*2@$AS?@(D%!&>D1(2\WI`((`(@?X""Q[
M1$9*>D0#DD_P_S+^]T+M(N<'FUQH`"P_]->N($;^]QSM`RA_]M&N/4D$."!$
M>43^]T;L`"@(OZ-&QN8@8(#G%_@"/$$KF=$7^`$\0RN5T3MX2"N2T7MX12N/
MT4_P_S-O\#D"($8`EO[WNNPI1BDB($;^]SCL*TLK24_P_S)[1,WI`E,I2WE$
M4$;-Z0"!>T0!(?[W`.W?YO[W:NP,`0``YMH!`'S9`0"&V0$`WA8``*07```T
M%P``$!<``!`6``#P%@``'`$```07``#XUP$`X!8``+@6``"0V`$`N!4``#85
M``"6%@``.!<``,`4``!$%P``RA0``'(6``!*%```2A4``'S6`0"D%````!0`
M`/83``#B$@``>!0``#P5``!"%```PA0``$X2``#J$P``7TA@27A$\+5?2X.P
M7TI!6'M$;D8):`&13_```9Q8(&C^]R#M!48@:/[W'.TQ1I7X:#"`^&DP5DAX
M1/[W?_X0L0-X,2MZT/_W<?H@:/[W"NU020,C`2)Y1/[W3NP%1FBQ(&C^]P#M
M*VE+2AEH>D3^]P[L*VD;:)MH6P)NU"!H_O?R[$9)`R,!(GE$_O<V[`5&>+%#
M2#%&>$3^]U#^!T8@:``O3]#^]][L*VDZ1AEH_O?NZR!H_O?6[`5&(&C^]]+L
M.$D!(GE$_O="[#=*`48H1GI$-DW^]]KK(&C^]\3L`T9]1#-(`"(Q1GA$@_AI
M(/[W)?X$1JA@L+%/].!Q($;^]T;L0AP#1A$H&+\!*B_8*4H<2WI$TU@::`&;
M6D!/\``#(]$#L/"]:&C_]X+\!$:H8``HX=$@2'A$_O<:[$-X`"N#T(#G_O>.
M[!Q+*FE[1!!H6V@9:/[WZ/ZKYR!H_O>"["MI&6C^]R3LB.?^]VKK%$DB1A1(
M>41X1$EH"6C^]_CKY-,!``P!``#8TP$`%`$``)@1```F$P``%!,````3``#R
M$```R!(``-02``"(U`$`E!```-;2`0!V$@``'-0!`/33`0!:$@``,DHS2WI$
M\+4'1H.PTU@;:`&33_```__W3?D#>`1&.[%"'"\K"+\41A+X`3L`*_C1*$X]
M'AB_`25^1#-H6APLT``K#+\`)07P`05=N2)*($MZ1--8&F@!FUI`3_```S+1
M`[#PO3MX`"OPT!Q)!"(@1GE$_O?\ZP`HZ-$92A1+>D336!IH`9M:0$_P``,;
MT3A&`["]Z/!`_O>SO1)(:49X1/[W:/UHL0-X`"L8OS`K"K\`(P$C,V#)T`$C
M,V``+<70T.<P8,+G_O?8Z@"_'-(!``P!```LTP$`T-$!`&`0``"BT0$`A@\`
M`"WI\$\`\4`!W_A@2]_X8#NM]2-]?$3N1G)&`/&`#``GXU@;:*&33_```U'I
M`F178-=@$#(VND+X$&PC"B4"`_1_0P@Q0^H48P7T?P5#Z@1C845#Z@4#0O@(
M/.;1K?$(!@[U_'<`(X1&-$96^`@/U.D&A2)OU/A(H&%OU/A,D(+J"@)T:(+J
M"`*!Z@D!0D!I0,;XA#!A0)08T@^^0D+J00)"Z@0"QOB`(-[18$;>^`!0W.D#
M)H1HW.D`>4_JE`@"F4CJ@GA']ID2Q?:"(DCJA'@$:JT83^K7;-WX$.!,ZDD<
M+1F$:4SJ1QP<ZP4%W?APH(;J!`R$:`SJ!`R$:8SJ!`P5ZPP%ANH(#(D8#.H'
M#`D9C.H&#!'K#`P>ZP(!3^J7#HD93NJ)?MWX&)!.ZH=T#.OU;(CJ!`X.Z@4.
M3^JU!8[J"`X1ZPX.&>L"`1'K"`&$Z@4(W?@@D`CJ#`B(Z@0(#NO\;A'K"`A/
MZKP,&>L"`=WX*)`)&87J#`0$Z@X$".O^:&Q`3^J^#@P9&>L"`4D9C.H.!=WX
M,)`%Z@@%A>H,!03K^&1-&4_JN`@9ZP(!W?@XD!'K#`&.Z@@,#.H$#`7K]&6,
MZ@X,3^JT!!'K#`P9ZP(!$>L.`8CJ!`[=^$"0#NH%#H[J"`X,Z_5L$>L.#D_J
MM049ZP(!W?A(D!'K"`&$Z@4(".H,"`[K_&Z(Z@0(3^J\#!'K"`@9ZP(!"1F%
MZ@P$W?A0D`3J#@1L0`CK_F@,&4_JO@X9ZP(!W?A8D$D9C.H.!07J"`4$Z_AD
MA>H,!4_JN`A-&1GK`@$1ZPP!CNH(#-WX8)`,Z@0,C.H.#`7K]&41ZPP,3^JT
M!!GK`@'=^&B0$>L.`8CJ!`X.Z@4.#.OU;([J"`Y/ZK4%$>L.#AGK`@$1ZP@!
MA.H%"`CJ#`@.Z_QNB.H$"$_JO`P1ZP@(&NL"`0D9A>H,!`CK_FD$Z@X$W?AX
M@&Q`3^J^#@D9&.L"!-WX@(!D&8SJ#@4%Z@D%`>OY887J#`5/ZKD)9!D8ZP(%
M%>L,!8[J"0S=^(B`#.H!#(SJ#@P$Z_%D%>L,#$_JL0$8ZP(%W?B0H!7K#@6)
MZ@$.#NH$#@SK]&R.Z@D.3^JT!!7K#@4:ZP(.'NL)#H'J!`D%Z_QH">H,"2:=
MB>H!"4_JO`P>ZPD.JAC=^*"@4AB$Z@P!`>H(`0[K^&YA0$_JN`51&$[VH3+&
M]MEBW?BH@!KK`@H!Z_YA&NL$!(SJ!0J*Z@X*3^J^#A3K"@3=^+"0&.L""(7J
M#@H$Z_%DBNH!"ACK#`Q/ZK$!W?BX@!SK"@P9ZP()CNH!"@SK]&R*Z@0*&>L%
M!4_JM`05ZPH%W?C`D!CK`@B!Z@0*!>O\98KJ#`H8ZPX.3^J\#![K"@[=^,B`
MA.H,"AGK`@F*Z@4*&>L!"0[K]6$9ZPH)3^JU!1CK`@K=^-#@&NL$"@GK\62,
MZ@4)B>H!"4_JL0$:ZPD*'NL""=WXV(`9ZPP)"NOT;(7J`0J*Z@0*3^JT!!GK
M"@D8ZP(*W?C@X!KK!0H)Z_QE@>H$"8GJ#`E/ZKP,&NL)"A[K`@G=^.B`&>L!
M"0KK]6&$Z@P*BNH%"D_JM049ZPH)&.L""-WX\.`8ZP0(">OQ9(SJ!0F)Z@$)
M3^JQ`1CK"0@>ZP(.W?CXH![K#`Z%Z@$,".OT:(SJ!`Q/ZK0$W?@`D1[K#`X:
MZP(,@>H$"@[K^&Z*Z@@*'.L%#$_JN`@<ZPH,0IV$Z@@*&>L""0SK_FR*Z@X*
M&>L!"4_JO@X9ZPH)1)FM&(CJ#@J*Z@P*+!D)Z_QE3^J\#!3K"@3=^!B1CNH,
M"HD8!.OU9(KJ!0H1ZP@!3^JU!1'K"@&,Z@4*&>L""0'K]&&*Z@0*W?@@@1GK
M#@E/ZK0+&>L*"=WX*.$)Z_%D&.L""(7J"PD8ZPP(B>H!"4_JL0$8ZPD)W?@P
MP1[K`@J+Z@$.CNH$#AKK!0H)Z_1E3^JT!!KK#@J!Z@0(W?@XX1SK`@R(Z@4(
M'.L+#`KK]6H<ZP@,3^JU!1[K`@)2&(3J!0'=^$#A@>H*`4_JN@A1&$OVW$+(
M]AMR#.OZ;![K`@Y%Z@@*W?A(D1[K!`0*Z@P*!>H(#@'K_&%*Z@X*3^J\#!3K
M"@X9ZP($9!E(Z@P%".H,"MWX4)$-0`[K\6Y%Z@H%3^JQ`2T9&>L""4SJ`009
MZP@*#.H!"]WX6)$$Z@X$!>O^943J"P1/ZKX.%.L*!!GK`@D9ZPP)0>H.#`'J
M#@K=^&"!#.H%#`3K]61,Z@H,3^JU!1SK"0P8ZP((&.L!`0SK]&A.Z@4,#NH%
M"MWX:)$,Z@0,3.H*#$_JM`0<ZP$,&>L""47J!`$9ZPX*!>H$"]WX<)$!Z@@!
M#.OX;$'J"P%/ZK@.$>L*`1GK`@D9ZP4*`>O\943J#@%/ZKP)W?AX@0'J#`$$
MZ@X,0>H,`1'K"@P8ZP(!"1E.Z@D$#NH)"MWX@($L0`SK]6Q$Z@H$3^JU!608
M2>H%"ACK`@@$Z_QD&.L."&*93^J\#@KJ#`H)Z@4,2NH,"AKK"`R)&!'K"0A%
MZ@X)!>H."F29">H$"0SK]&Q)Z@H)3^JT!!GK"`B)&$D93NH$!0[J!`D%Z@P%
M1>H)!0CK_&AM&&:93^J\#`7K^&6)&$3J#`D$Z@P*$>L.#@GJ"`EHF4GJ"@E/
MZK@(&>L."8D8$>L$#@GK]61,Z@@)#.H("FJ9">H%"4GJ"@E/ZK4%&>L.#HD8
M$>L,`4CJ!0P(Z@4)#.H$#$SJ"0P.Z_1N'.L!#&R93^JT!`SK_FR)&$7J!`D%
MZ@0*$>L("`GJ#@ENF4GJ"@E/ZKX.&>L("8D8$>L%"`GK_&5$Z@X)!.H."G"9
M">H,"4GJ"@E/ZKP,&>L("4[J#`B)&`CJ!0@)&0GK]60.Z@P)3^JU!4CJ"0A,
MZ@4)&.L!"'*9#.H%"@GJ!`F)&`CK]&@1ZPX.=)E/ZK0$2>H*"1GK#@F)&$7J
M!`X)Z_AI$>L,"@[J"`Y/ZK@,=ID%Z@0(0V!.Z@@.!.H,"![K"@Z*&%(91.H,
M!07J"05XF47J"`4.Z_ENK1A,\M82S/9B(D_JN0D1ZP((>ID8ZP0(C.H)!(3J
M#@0%Z_YE&.L$"$_JO@Z)&(GJ#@01ZPP,?)EL0`CK]6@<ZP0,3^JU!8D8CNH%
M!!'K"0E^F0SK^&R$Z@@$&>L$"4_JN`B,&("9%.L.!`GK_&Z%Z@@)PV")Z@P)
M3^J\#!3K"001ZP()&>L%"8*9B.H,!03K_F2%Z@X%3^J^#AGK!0F-&!7K"`6$
MF0GK]&B,Z@X)B>H$"4_JM`05ZPD%$>L""1GK#`F&F8[J!`P%Z_AEC.H(#$-A
M&>L,"4_JN`P1ZP((B)D8ZPX(">OU;H3J#`G#88GJ!0E/ZK4%&.L)"!'K`@D9
MZP0)BID(Z_YDC.H%"(CJ#@A/ZKX.&>L("1'K`@@8ZPP(C)D)Z_1LA>H."8GJ
M!`E/ZK0$&.L)"!'K`@D9ZP4)CID(Z_QECNH$"(CJ#`A/ZKP,&>L("1'K`@@8
MZPX(D)D)Z_5NA.H,"8GJ!0E/ZK4%&.L)"!'K`@D9ZP0)DID(Z_YDC.H%"(CJ
M#@A/ZKX.&>L("1'K`@@8ZPP(E)D)Z_1LA>H."8GJ!`E/ZK0$&.L)"!'K`@D9
MZP4)EID(Z_QECNH$"(CJ#`A/ZKP,&>L("1'K`@@8ZPX(F)D)Z_5NA.H,"8GJ
M!0E/ZK4%&.L)"(D8$>L$"0CK_F2:F8SJ!0B(Z@X(3^J^#AGK"`F)&!'K#`@)
MZ_1LA>H."9R9B>H$"4_JM`08ZPD)B1@)Z_QI31F>F0;KN08&88[J!`:&Z@P&
M3^J\#*T9BAC2&83J#`&!Z@D!$NL.`@7K^652&(%H`NOU8FD8A6D"8`)J'.L%
M!8%@I!@+2L#I"$,)2WI$A6'36!IHH9M:0$_P``,#T0WU(WV]Z/"/_?<4[0"_
M)-$!``P!``#LQ0$`"+6`(/WW6.V?[0][`"*"9X#M`'N?[0Y[@.T">Y_M#GN`
M[01[G^T.>X#M!GN?[0Y[@.T(>Y_M#GN`[0I[@.T,>PB]`+^O\P"``2-%9P``
M``")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````````````+>GX
M0P5&%D:`:@`C#$;W%]7I#"$`Z\8,A$7H:G/K```"T@$R0?$``:AO!?$X",7I
M"L-S#T/JQP.;&"MC0>M7<6EC@+L_+D/=IO%`"4_JF19W'`3KAQ<A1D-&!/%`
M#M'X`,`0,5'X#$P0,U'X"`Q1^`0L<45#^!#,0_@,3$/X"`Q#^`0LZ]$,1BA&
M__?!^;Q"X=&IZX86,D8Y1D!&_?=4[*YGO>CX@\#Q0`<A1K="0$2HOS=&.D;]
M]TCLJV\[1*MG0"ONT2A&]AL\1/_WH?FYYR=&X.<MZ?!!`?$X!PQ&BVH%1@YK
M@"&3^H/XP_/%`S:Z6ARX&#@J^51$W<+Q0`(`(?WW^NP@1O_W@_DX1C@B`"']
M]_+L($;$Z1QH__=Y^>-X*W`@1F.(:W`C:!L*JW`C:.MPXWHK<6.):W&C:!L*
MJW&C:.MQXWPK<F.*:W(C:1L*JW(C:>MRXWXK<V.+:W.C:1L*JW.C:>MSE/@C
M,"MT8XQK="-J&PJK="-JZW2]Z/!!_??:N\+Q.`(`(?WWMNS!YRWI^$,'1@Q.
M#$V(1GY$D49]1/WWD.MV&[80"M`$/0`D5?@$/TI&048X1@$TF$>F0O;1O>CX
M@P"_F,(!`)#"`0!P1P"_`DM[1!MH_??GNP"_LL0!``A`+>D(@+WH`0`"`#L`
M```^````"P```#X````0````/@```"4````^````,P```#X````#````/@``
M``8````^````%````#X````.````/@````T````^````)````#X````2````
M/@```"<````^`````@```#X````8````/@````D````^````"@```#X`````
M`````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E
M:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````
M)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M``!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'````
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`````,0```$Q$7TQ)0E)!4EE?4$%42`!3
M65-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0
M051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E
M;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,```
M`%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4U````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M```M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M
M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q
M6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,
M24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP
M<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G
M(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O
M;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L
M("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R
M/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*
M?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA
M;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T
M87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM>2`D;6%G:6-?
M<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C($Y/5$4Z("1M
M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H
M)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P.PIR
M96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)
M0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X]
M(#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]
M("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q
M6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE
M("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2
M(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*;7D@)&]F9G-E
M="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R
M="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@-"`M("1O9F9S970L(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E
M<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H
M)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U
M9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5]
M.PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D
M92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[
M9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL
M96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG
M="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D
M9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D
M9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N
M86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U
M:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P
M,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C
M=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S
M=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE
M+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2
M155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R
M;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B
M=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*
M<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T
M(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*
M9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A
M8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8
M(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII
M9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K
M97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@
M>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D
M9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D[
M"FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI
M('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI
M;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E
M9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@
M)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@
M(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I
M='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0HD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A
M)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@
M>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D=&@L
M("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)'1H*3L*8VQO<V4@)'1H
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0P("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(EPP0T%#2$4B.PIM>2`D;V9F<V5T(#T@)&9H+3YT96QL("L@
M;&5N9W1H*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!
M1TE#*0HF)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R
M86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70[
M"GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O
M9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A
M;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;W5T<R@B4F5A9&EN9R!-151!+GEM;"XN+B(I.PII9B`H;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CI<<RHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["FEF
M("AM>2`H)&-L96%N*2`]("1M971A(#U^("]>7',K8VQE86XZ("@N*BDD+VTI
M('L*)&-L96%N(#U^("]>7',J?%QS*B0O9SL*)$5.5GM005)?0TQ%04Y](#T@
M,2!I9B`D8VQE86X["GT*?0IP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C
M=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S
M*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@
M97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N
M86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["G-E
M96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V.PII
M9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<F5A
M9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]
M("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S
M="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG
M97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S
M=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UC86-H
M92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#
M3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?
M87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F
M=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL
M;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H
M.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F
M:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]
M"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[
M7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N
M86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S
M>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%2
M7T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT[
M"GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G
M9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?
M7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M
M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P
M87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A
M;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL
M92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P```#L````^````"P```#X````0
M````/@```"4````^````,P```#X````#````/@````8````^````%````#X`
M```.````/@````T````^````)````#X````2````/@```"<````^`````@``
M`#X````8````/@````D````^````"@```#X``````````````)B:_W\!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````1&```T1<```$````;`P```0```"L#```!````.P,```$```!%`P``
M#````#P2```-````7#L``!D```"L_0$`&P````0````:````L/T!`!P````$
M````]?[_;[0!```%````5`D```8```"D`@``"@```-@$```+````$````!4`
M`````````P```,3^`0`"````Z`$``!0````1````%P```%00```1````=`\`
M`!(```#@````$P````@````>````"````/O__V\!```(_O__;P0/``#___]O
M`P```/#__V\L#@``^O__;Q``````````````````````````````````````
M````````````````````M/T!````````````2!(``$@2``!($@``2!(``$@2
M``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(`
M`$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``
M2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!(
M$@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2
M``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(``$@2``!($@``2!(`
M`$D[``````````````````````````````````````````````D[````````
M214````````````````````````$``(`_____Q@_``!4/````````!0]```8
M/0``##\``%P\```4/P```````/@^````/P```````"`_``!'0T,Z("A$96)I
M86X@,3$N,RXP+30I(#$Q+C,N,`!!,@```&%E86)I``$H````!3<M00`&"@=!
M"`$)`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-
M+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S
M``````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``\`````4`````````!`````0````^````"P````(```"D`@``I`(``+`&
M```&`````P````0````0````1@````,````"````5`D``%0)``#8!```````
M```````!`````````$X```#___]O`@```"P.```L#@``U@````4`````````
M`@````(```!;````_O__;P(````$#P``!`\``'`````&`````P````0`````
M````:@````D````"````=`\``'0/``#@````!0`````````$````"````',`
M```)````0@```%00``!4$```Z`$```4````5````!`````@```!\`````0``
M``8````\$@``/!(```P```````````````0`````````=P````$````&````
M2!(``$@2`````P`````````````$````!````((````!````!@```$@5``!(
M%0``%"8`````````````"`````````"(`````0````8```!<.P``7#L```@`
M``````````````0`````````C@````$````"````9#L``&0[```(00``````
M```````$`````````)8````!``!P@@```&Q\``!L?```"`````T`````````
M!`````````"A`````0````(```!T?```='P```0```````````````0`````
M````JP````X````#````K/T!`*S]```$```````````````$````!````+<`
M```/`````P```+#]`0"P_0``!```````````````!`````0```##````!@``
M``,```"T_0$`M/T``!`!```&``````````0````(````S`````$````#````
MQ/X!`,3^```\`0`````````````$````!````-$````!`````P```````@``
M``$`0```````````````!`````````#7````"`````,```!```(`0``!`!00
M``````````````0`````````W`````$````P`````````$```0`>````````
M```````!`````0```.4````#``!P``````````!>``$`,P``````````````
M`0`````````!`````P``````````````D0`!`/4```````````````$`````
#````
